@@ -10,8 +10,8 @@
 #' @inheritParams pof_cables_132kv
 #' @param simulation_end_year Numeric. The last year of simulating probability
 #'  of failure. Default is 100.
-#' @return Numeric array. Future probability of failure
-#' per annum per kilometre for 132kV cables.
+#' @return DataFrame. Future probability of failure
+#' along with future health score
 #' @source DNO Common Network Asset Indices Methodology (CNAIM),
 #' Health & Criticality - Version 2.1, 2021:
 #' \url{https://www.ofgem.gov.uk/sites/default/files/docs/2021/04/dno_common_network_asset_indices_methodology_v2.1_final_01-04-2021.pdf}
@@ -19,16 +19,16 @@
 #' @examples
 #' # Future probability of failure for 132kV UG Cable (Non Pressurised)
 #' pof_future_cables_132kv(cable_type = "132kV UG Cable (Non Pressurised)",
-#'sub_division = "Aluminium sheath - Aluminium conductor",
-#'utilisation_pct = 75,
-#'operating_voltage_pct = 50,
-#'sheath_test = "Default",
-#'partial_discharge = "Default",
-#'fault_hist = "Default",
-#'leakage = "Default",
-#'reliability_factor = "Default",
-#'age = 1,
-#'simulation_end_year = 100)
+#' sub_division = "Aluminium sheath - Aluminium conductor",
+#' utilisation_pct = 75,
+#' operating_voltage_pct = 50,
+#' sheath_test = "Default",
+#' partial_discharge = "Default",
+#' fault_hist = "Default",
+#' leakage = "Default",
+#' reliability_factor = "Default",
+#' age = 1,
+#' simulation_end_year = 100)
 pof_future_cables_132kv <-
   function(cable_type = "132kV UG Cable (Gas)",
            sub_division = "Aluminium sheath - Aluminium conductor",
@@ -346,6 +346,7 @@ pof_future_cables_132kv <-
 
     # Dynamic part
     pof_year <- list()
+    future_health_score_list <- list()
     year <- seq(from=0,to=simulation_end_year,by=1)
 
     for (y in 1:length(year)){
@@ -361,12 +362,16 @@ pof_future_cables_132kv <-
       } else if (H < 4) {
         H <- 4
       }
+      future_health_score_list[[paste(y)]] <- future_health_Score
       pof_year[[paste(y)]] <- k * (1 + (c * H) +
                                      (((c * H)^2) / factorial(2)) +
                                      (((c * H)^3) / factorial(3)))
     }
 
-    pof_future <- data.frame(year=year, PoF=as.numeric(unlist(pof_year)))
+    pof_future <- data.frame(
+      year=year,
+      PoF=as.numeric(unlist(pof_year)),
+      future_health_score = as.numeric(unlist(future_health_score_list)))
     pof_future$age <- NA
     pof_future$age[1] <- age
 
