@@ -4,7 +4,6 @@ library(CNAIM)
 context("Current Probability of Failure for 66kV OHL (Tower Line) Conductor")
 
 test_that("pof_ohl_cond_132_66_33kv", {
-  # TODO: verify correctness
 
   res <- pof_ohl_cond_132_66_33kv(ohl_conductor = "66kV OHL (Tower Line) Conductor",
                                   sub_division = "Cu",
@@ -17,9 +16,11 @@ test_that("pof_ohl_cond_132_66_33kv", {
                                   corr_mon_survey = "Medium/Normal",
                                   visual_cond = "Normal Wear",
                                   midspan_joints = 3,
-                                  reliability_factor = "Default")
+                                  reliability_factor = "Default") %>% round(5)
 
-  expect_equal(res, 0.004837129)
+  expected_val <- data.frame(pof = 0.00484, chs = 5.5)
+
+  expect_equal(res, expected_val)
 
 })
 
